@@ -2,7 +2,7 @@ package Config::IniFiles;
 
 use vars qw($VERSION);
 
-$VERSION = '2.86';
+$VERSION = '2.87';
 
 require 5.008;
 use strict;
@@ -11,7 +11,7 @@ use Carp;
 use Symbol 'gensym','qualify_to_ref';   # For the 'any data type' hack
 use Fcntl qw( SEEK_SET SEEK_CUR );
 
-use List::MoreUtils qw(any none);
+use List::Util qw(any none);
 
 use File::Basename qw( dirname );
 use File::Temp qw/ tempfile /;
@@ -1083,7 +1083,7 @@ sub _ReadConfig_handle_non_here_doc_param
 
     # we should split value and comments if there is any comment
     if ($end_commenthandle and
-        my ($value_to_assign, $end_comment_to_assign) = $self->_curr_val =~ /(.*?)\s*[$allCmt]\s*([^$allCmt]*)$/)
+        my ($value_to_assign, $end_comment_to_assign) = $self->_curr_val =~ /(.*?)\s*[$allCmt]\s*(.*)$/)
     {
         $self->_curr_val($value_to_assign);
         $self->_curr_end_comment($end_comment_to_assign);
